/*  display.h -- Table display definitions

    The central structure for controlling the display of table records is an
    array whose elements contain the index number of the field in the FITS
    table file and the starting column on the screen in which to display that
    field. Two integers hold the number of fields to display and the total
    width of the display record, respectively.

    The overall structure is an array of pointers -- one for each table -- to
    the central structures.

    Written by Lee E. Brotzman, Hughes STX
    Written for Astronomical Data Center, NASA Goddard Space Flight Center

    This code is in the Public Domain, but no warranty, expressed or implied,
    is made by Hughes STX, NASA, or the ADC as to the accuracy and functioning
    of the software.
*/
#ifndef __DISPLAY_H
#define __DISPLAY_H

typedef struct {        /* Structure for holding single display descriptor */
   int tabfield;        /* Field number in the table */
   int dispcol;         /* Starting column on screen for display */
}  disp_pos;

typedef struct {                 /* Structure for holding table descriptors */
   int       count;              /* Number of display descriptors */
   int       width;              /* Total width of display record */
   disp_pos  field[MAXFIELDS];   /* Pointers to display descriptors */
   int       currcol;            /* Index of next free display column */
   char      *used;              /* Record showing filled display columns */
}  disp_t;

extern disp_t *display[MAXTABLES];  /* Global display data structure */

/*
   Function prototypes for display.c
*/
void    BuildDisplay(int tableno, long recno);
void    CopyDisplay(int tableno);
void    Display(char *cmdline);
void    FreeDisplay(int tableno);
disp_t  *NewDisplay(void);
#endif
