/*  ftb.h -- Main program header file

    This file defines global constants used throughout the program.

    Written by Lee E. Brotzman, Hughes STX
    Written for Astronomical Data Center, NASA Goddard Space Flight Center

    This code is in the Public Domain, but no warranty, expressed or implied,
    is made by Hughes STX, NASA, or the ADC as to the accuracy and functioning
    of the software.
*/
#ifndef __FTB_H
#define __FTB_H

#include <stdio.h>
#include <setjmp.h>

#ifndef TRUE
#define TRUE 1
#endif
#ifndef FALSE
#define FALSE 0
#endif
#define VERNO "3.0"

/*
    Define limits on tables and fields
*/
#define FITSLEN 2880
#define FITSLENL 2880L
#define CMDLEN 127
#define MAXTABLES 21
#define MAXFILES 21
#define MAXFIELDS 999
#define MAXCHECKS 10

/*
    Define limits on the screen elements
*/
#define MAXCWD 80
#define MAXDISP 2000
#define MAXTEXT 1000

/*
    Structure for holding global SET parameters
*/
typedef struct {
    int     batch;              /* Flag for browse mode (internal use only) */
    int     browse;             /* Flag for browse mode (internal use only) */
    char    contchar;           /* Command line continuation character      */
    int     curses;             /* Flag for curses mode (internal use only) */
    char    defcmd[CMDLEN];     /* Default command; see FTB.C, BROWSE.C     */
    int     echo;               /* Flag for echoing input commands          */
    int     number;             /* Flag for displaying record numbers in    */
                                /*      browse mode. See DISPLAY.C          */
    int     table;              /* Current table number                     */
    int     update;             /* Flag to control update in browse mode    */
    int     wrap;               /* Flag to control word wrap.  See SCREEN.C */
}   set_t;
extern set_t SET;

/*
   External data
*/
extern int   FILES;
extern int   TABLES;
extern FILE *helpfile;
extern char  helpfilename[];
extern char  currdir[];
extern long  recno;
extern char  outrec[MAXDISP];
extern char  *text[MAXTEXT];
extern jmp_buf CmdJmp;

/*
   UNIX/DOS variations
*/
#ifndef max
#define max(a,b)         (((a) > (b)) ? (a) : (b))
#endif
#ifndef min
#define min(a,b)         (((a) < (b)) ? (a) : (b))
#endif
#ifdef unix
#define stricmp(A,B)     strcasecmp((A),(B))
#define strnicmp(A,B,C)  strncasecmp((A),(B),(C))
#define PATHCHAR "/"
#define PATHSEP ":"
#else
#define PATHCHAR "\\"
#define PATHSEP ";"
#endif

#endif
