/*  select.h -- Table record selection specification header file

    This file defines the structures that hold the specifications for the
    selection of individual records from a FITS table. A 'multi'-type value can
    be either boolean (int), double floating point, or character. The data type
    is governed by the specification for the field that refers to that value.
    The selection expression is converted from infix to postfix and is stored
    and evaluated on a set of stacks, according to the algorithm given in
    Horowitz and Sahni 1976, pp. 91-97 (who says that old dogs can't teach us
    new tricks ... or something like that).

    Evaluation of the resulting postfix expression is performed by pushing the
    operands onto the stack and performing the desired operations.

    Written by Lee E. Brotzman, Hughes STX
    Written for Astronomical Data Center, NASA Goddard Space Flight Center

    This code is in the Public Domain, but no warranty, expressed or implied,
    is made by Hughes STX, NASA, or the ADC as to the accuracy and functioning
    of the software.
*/
#ifndef __SELECT_H
#define __SELECT_H

extern char OPS[12][10];    /* List of string values for logical operators  */
                        /* See Initialize() in ftb.c for initial values */
enum logop { L_AND, L_OR, L_NOT, L_EQ, L_NE, L_LT,
             L_GT,  L_GE, L_LE,  L_SE, L_IN, L_NONE };
enum celltype { C_LPAREN, C_FIELD, C_NULL, C_BOOL, C_FLOAT, C_CHAR, C_LOGOP };

typedef union {
    int     I;
    double  F;
    char    *A;
}   multi_t;

typedef struct cell {
    enum celltype type;
    enum logop    operator;
    multi_t       value;
}   cell_t;

void Select(char *cmdline);     /* Set record selection criteria */
void PrintSel(int tableno);
void Postfix(int tableno, char *expression);
int  Evaluate(int tableno);

#endif
